@@ -3,7 +3,6 @@ module Tmuxinator
     include Tmuxinator::Util
     include Tmuxinator::Deprecations
     include Tmuxinator::Hooks::Project
-    include Tmuxinator::WemuxSupport
 
     RBENVRVM_DEP_MSG = <<-M
     DEPRECATION: rbenv/rvm-specific options have been replaced by the
@@ -27,17 +26,12 @@ module Tmuxinator
     now, use the 'synchronize: after' option.
     M
     PRE_DEP_MSG = <<-M
-    DEPRECATION: The `pre` option has been replaced by project hooks and will
-    not be supported anymore.
+    DEPRECATION: The `pre` option has been replaced by project hooks (`on_project_start` and
+    `on_project_restart`) and will be removed in a future release.
     M
     POST_DEP_MSG = <<-M
-    DEPRECATION: The `post` option has been replaced by project hooks and will
-    not be supported anymore.
-    M
-    TMUX_MASTER_DEP_MSG = <<-M
-    DEPRECATION: You are running tmuxinator with an unsupported version of tmux.
-    Please consider using a supported version:
-    (#{Tmuxinator::SUPPORTED_TMUX_VERSIONS.join(', ')})
+    DEPRECATION: The `post` option has been replaced by project hooks (`on_project_stop` and
+    `on_project_exit`) and will be removed in a future release.
     M
 
     attr_reader :yaml
@@ -96,7 +90,7 @@ module Tmuxinator
       raise "Cannot force_attach and force_detach at the same time" \
         if @force_attach && @force_detach
 
-      load_wemux_overrides if wemux?
+      extend Tmuxinator::WemuxSupport if wemux?
     end
 
     def render
@@ -276,8 +270,7 @@ module Tmuxinator
         cli_args?,
         legacy_synchronize?,
         pre?,
-        post?,
-        unsupported_version?
+        post?
       ]
     end
 
@@ -288,8 +281,7 @@ module Tmuxinator
         CLIARGS_DEP_MSG,
         SYNC_DEP_MSG,
         PRE_DEP_MSG,
-        POST_DEP_MSG,
-        TMUX_MASTER_DEP_MSG
+        POST_DEP_MSG
       ]
     end
 
@@ -321,10 +313,6 @@ module Tmuxinator
       yaml["post"]
     end
 
-    def unsupported_version?
-      !Tmuxinator::SUPPORTED_TMUX_VERSIONS.include?(Tmuxinator::Config.version)
-    end
-
     def get_pane_base_index
       tmux_config["pane-base-index"]
     end
@@ -389,5 +377,9 @@ module Tmuxinator
     def parsed_parameters(parameters)
       parameters.is_a?(Array) ? parameters.join("; ") : parameters
     end
+
+    def wemux?
+      yaml["tmux_command"] == "wemux"
+    end
   end
 end
